@@ -7,7 +7,7 @@ from .layout import Layout
 from .info import InfoStyle
 from typing import Any, Callable, Iterator, Optional, Sequence, Type, Union
 
-__version__ = "0.0.14"
+__version__ = "0.0.15"
 "PZP Version"
 
 __all__ = ["pzp", "CustomAction"]
@@ -26,10 +26,14 @@ def pzp(
     keys_binding: Optional[KeysBinding] = None,
     matcher: Union[Matcher, Type[Matcher], str] = DEFAULT_MATCHER,
     input: Optional[str] = None,
+    lazy: bool = False,
 ) -> Any:
     """
     Open pzp and return the selected element
 
+    If the Lazy mode is enabled, starts the finder only if the candidates are more than one.
+    If there is only one match returns the only match, if there is no match returns None.
+
     Examples:
         >>> pzp(candidates=list(Path('.').iterdir()))
         PosixPath('README.md')
@@ -46,6 +50,7 @@ def pzp(
         header_str: Header
         keys_binding: Custom keys binding
         matcher: Matcher
+        lazy: Lazy mode, starts the finder only if the candidates are more than one
 
     Returns:
         item: the selected item
@@ -63,4 +68,9 @@ def pzp(
         keys_binding=keys_binding,
         matcher=matcher,
     )
+    if lazy:
+        if finder.candidates.candidates_len == 0:
+            return None
+        elif finder.candidates.candidates_len == 1:
+            return finder.candidates.candidates[0]
     return finder.show(input=input)
